@@ -36,8 +36,13 @@ def asoctal(s):
     """Convert the given octal string to an actual number."""
     return int(s, 8)
 
-def slash_suffix_stripped_str(s):
-    return s.rstrip('/')
+def slash_fixed_str(s):
+    s = s.strip()
+    if s:
+        # always have a leading slash, replace any number of leading slashes
+        # with a single slash, and strip any trailing slashes
+        s = '/' + s.lstrip('/').rstrip('/')
+    return s
 
 class Adjustments(object):
     """This class contains tunable parameters.
@@ -48,7 +53,7 @@ class Adjustments(object):
         ('port', int),
         ('threads', int),
         ('url_scheme', str),
-        ('url_prefix', slash_suffix_stripped_str),
+        ('url_prefix', slash_fixed_str),
         ('backlog', int),
         ('recv_bytes', int),
         ('send_bytes', int),
@@ -176,7 +181,10 @@ class Adjustments(object):
 
     @classmethod
     def parse_args(cls, argv):
-        """Parse command line arguments.
+        """Pre-parse command line arguments for input into __init__.  Note that
+        this does not cast values into adjustment types, it just creates a
+        dictionary suitable for passing into __init__, where __init__ does the
+        casting.
         """
         long_opts = ['help', 'call']
         for opt, cast in cls._params:
@@ -196,9 +204,11 @@ class Adjustments(object):
             param = opt.lstrip('-').replace('-', '_')
             if param.startswith('no_'):
                 param = param[3:]
-                kw[param] = False
-            elif param in ('help', 'call') or cls._param_map[param] is asbool:
+                kw[param] = 'false'
+            elif param in ('help', 'call'):
                 kw[param] = True
+            elif cls._param_map[param] is asbool:
+                kw[param] = 'true'
             else:
-                kw[param] = cls._param_map[param](value)
+                kw[param] = value
         return kw, args
