@@ -17,6 +17,7 @@
 from __future__ import print_function, unicode_literals
 
 import getopt
+import os
 import os.path
 import re
 import sys
@@ -57,6 +58,13 @@ Standard options:
     --url-scheme=STR
         Default wsgi.url_scheme value, default is 'http'.
 
+   --url-prefix=STR
+        The ``SCRIPT_NAME`` WSGI environment value.  Setting this to anything
+        except the empty string will cause the WSGI ``SCRIPT_NAME`` value to be
+        the value passed minus any trailing slashes you add, and it will cause
+        the ``PATH_INFO`` of any request which is prefixed with this value to
+        be stripped of the prefix.  Default is the empty string.
+
     --ident=STR
         Server identity used in the 'Server' header in responses. Default
         is 'waitress'.
@@ -115,6 +123,11 @@ Tuning options:
 
     --asyncore-loop-timeout=INT
         The timeout value in seconds passed to asyncore.loop(). Default is 1.
+
+    --asyncore-use-poll
+        The use_poll argument passed to ``asyncore.loop()``. Helps overcome
+        open file descriptors limit. Default is False.
+
 """
 
 RUNNER_PATTERN = re.compile(r"""
@@ -153,7 +166,7 @@ def resolve(module_name, object_name):
         obj = getattr(obj, segment)
     return obj
 
-def show_help(stream, name, error=None):  # pragma: no cover
+def show_help(stream, name, error=None): # pragma: no cover
     if error is not None:
         print('Error: {0}\n'.format(error), file=stream)
     print(HELP.format(name), file=stream)
@@ -182,6 +195,9 @@ def run(argv=sys.argv, _serve=serve):
         show_help(sys.stderr, name, str(exc))
         return 1
 
+    # Add the current directory onto sys.path
+    sys.path.append(os.getcwd())
+
     # Get the WSGI function.
     try:
         app = resolve(module, obj_name)
