@@ -1,14 +1,14 @@
-def chunks(l, n):
+def chunks(l, n): # pragma: no cover
     """ Yield successive n-sized chunks from l.
     """
     for i in range(0, len(l), n):
         yield l[i:i + n]
 
-def gen(body):
+def gen(body): # pragma: no cover
     for chunk in chunks(body, 10):
         yield chunk
 
-def app(environ, start_response):
+def app(environ, start_response): # pragma: no cover
     cl = environ.get('CONTENT_LENGTH', None)
     if cl is not None:
         cl = int(cl)
@@ -22,7 +22,3 @@ def app(environ, start_response):
     if environ['PATH_INFO'] == '/list_lentwo':
         return [body[0:1], body[1:]]
     return gen(body)
-
-if __name__ == '__main__':
-    from waitress.tests.support import start_server
-    start_server(app, expose_tracebacks=True)
