@@ -1,6 +1,5 @@
 import errno
 import socket
-import sys
 import unittest
 
 class TestWSGIServer(unittest.TestCase):
@@ -191,7 +190,7 @@ class TestWSGIServer(unittest.TestCase):
         self.assertNotEqual(Adjustments.port, 1234)
         self.assertEqual(inst.adj.port, 1234)
 
-if not sys.platform.startswith('win'):
+if hasattr(socket, 'AF_UNIX'):
 
     class TestUnixWSGIServer(unittest.TestCase):
         unix_socket = '/tmp/waitress.test.sock'
@@ -311,7 +310,7 @@ class DummyAdj:
 
 class DummyAsyncore(object):
 
-    def loop(self, timeout=None, map=None):
+    def loop(self, timeout=30.0, use_poll=False, map=None, count=None):
         raise SystemExit
 
 class DummyTrigger(object):
