@@ -394,6 +394,16 @@ class TestWSGITask(unittest.TestCase):
         inst.channel.server.application = app
         self.assertRaises(AssertionError, inst.execute)
 
+    def test_preserve_header_value_order(self):
+        def app(environ, start_response):
+            write = start_response('200 OK', [('C', 'b'), ('A', 'b'), ('A', 'a')])
+            write(b'abc')
+            return []
+        inst = self._makeOne()
+        inst.channel.server.application = app
+        inst.execute()
+        self.assertTrue(b'A: b\r\nA: a\r\nC: b\r\n' in inst.channel.written)
+
     def test_execute_bad_status_value(self):
         def app(environ, start_response):
             start_response(None, [])
@@ -548,7 +558,7 @@ class TestWSGITask(unittest.TestCase):
         request.path = ''
         inst.request = request
         environ = inst.get_environment()
-        self.assertEqual(environ['PATH_INFO'], '/')
+        self.assertEqual(environ['PATH_INFO'], '')
 
     def test_get_environment_no_query(self):
         inst = self._makeOne()
@@ -585,6 +595,16 @@ class TestWSGITask(unittest.TestCase):
         self.assertEqual(environ['PATH_INFO'], '/fuz')
         self.assertEqual(environ['SCRIPT_NAME'], '/foo')
 
+    def test_get_environ_with_url_prefix_empty_path(self):
+        inst = self._makeOne()
+        inst.channel.server.adj.url_prefix = '/foo'
+        request = DummyParser()
+        request.path = '/foo'
+        inst.request = request
+        environ = inst.get_environment()
+        self.assertEqual(environ['PATH_INFO'], '')
+        self.assertEqual(environ['SCRIPT_NAME'], '/foo')
+
     def test_get_environment_values(self):
         import sys
         inst = self._makeOne()
